@@ -1,3 +1,4 @@
+import datetime as dt
 from abc import ABCMeta, abstractmethod
 from typing import Any
 
@@ -14,11 +15,12 @@ class Producer(metaclass=ABCMeta):
         self.close()
 
     @abstractmethod
-    def send(self, *records: Any):
+    def send(self, record: Any, partition_key: str = None):
         """
         发送数据
 
-        :param records: 数据
+        :param record: 数据
+        :param partition_key: 用于划分数据的key
         """
 
     @abstractmethod
@@ -40,6 +42,13 @@ class Message(metaclass=ABCMeta):
         消息内容
         """
 
+    @property
+    @abstractmethod
+    def publish_time(self) -> dt.datetime:
+        """
+        消息发布时间
+        """
+
 
 class Consumer(metaclass=ABCMeta):
     """
@@ -91,6 +100,7 @@ class DataHub(metaclass=ABCMeta):
             self,
             topic: str,
             subscription_name: str = None,
+            consumer_name: str = None,
             auto_ack: bool = True,
     ) -> Consumer:
         """
@@ -98,5 +108,6 @@ class DataHub(metaclass=ABCMeta):
 
         :param topic: topic名称
         :param subscription_name: 订阅的标识
+        :param consumer_name: 消费者名称
         :param auto_ack: 自动确认
         """
